@@ -3,14 +3,15 @@
 # 创建时间：2022-01-16
 
 
-import yaml
 import sys
 
+import yaml
+
 ROOT_PATH = sys.path[0]  # 项目根目录
 
 
 # 脚本参数
 def argsYaml(args):
-    with open(f'{ROOT_PATH}/args.yaml', 'w') as f:
+    with open(f"{ROOT_PATH}/args.yaml", "w") as f:
         # 脚本参数yaml保存
         yaml.safe_dump(vars(args), f, sort_keys=False)
