@@ -4,11 +4,13 @@
 
 import sys
 
+from opencv_webcam.utils.fonts_opt import info_warning
+
 
 # 判断时间格式
 def is_time(preTime):
-    if (preTime <= 0):
-        print(f'时间格式不正确！程序结束！')
+    if preTime <= 0:
+        print(f'{info_warning("时间格式不正确！程序结束！")[2]}')
         sys.exit()
 
 
@@ -20,23 +22,23 @@ def time_format(preTime):
     h = int(h)  # 转整型
     m = int(m)  # 转整型
 
-    if (0 < s < 1):
-        time_str = f'{s:.3f}秒'
+    if 0 < s < 1:
+        time_str = f"{s:.3f}秒"
         return time_str
-    elif (h == 0 and m == 0 and s >= 1):
-        time_str = f'{s:.3f}秒'
+    elif h == 0 and m == 0 and s >= 1:
+        time_str = f"{s:.3f}秒"
         return time_str
-    elif (h == 0 and m > 0):
-        time_str = f'{m}分{s:.3f}秒'
+    elif h == 0 and m > 0:
+        time_str = f"{m}分{s:.3f}秒"
         return time_str
-    elif (h > 0):
-        if (h >= 24):
+    elif h > 0:
+        if h >= 24:
             d = int(h / 24)  # 以天为单位
             h2 = h - 24
-            time_str = f'{d}天{h2}时{m}分{s:.3f}秒'
+            time_str = f"{d}天{h2}时{m}分{s:.3f}秒"
         else:
-            time_str = f'{h}时{m}分{s:.3f}秒'
+            time_str = f"{h}时{m}分{s:.3f}秒"
         return time_str
     else:
-        print(f'时间格式化失败！程序结束！')
+        print(f'{info_warning("时间格式化失败！程序结束！")[2]}')
         sys.exit()
